@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
+from plone.app.event.base import find_navroot
 from plone.app.event.base import find_ploneroot
-from plone.app.event.base import find_site
+
+import six
 
 
 def get_calendar_url(context, search_base):
@@ -10,13 +12,14 @@ def get_calendar_url(context, search_base):
     calendar_url = None
     if search_base:
         portal = find_ploneroot(context)
-        if isinstance(search_base, unicode):
+        if six.PY2 and isinstance(search_base, six.text_type):
             search_base = search_base.encode('utf8')
+        search_base = '/'.join(search_base.split('/')[2:])
         calendar_url = portal.unrestrictedTraverse(
             search_base.lstrip('/')  # start relative, first slash is omitted
         ).absolute_url()
     else:
-        site_url = find_site(context, as_url=True)
+        site_url = find_navroot(context, as_url=True)
         calendar_url = '%s/event_listing' % site_url
 
     return calendar_url
